@@ -268,7 +268,7 @@ class Ui_MainWindow(QtCore.QObject):
         icon = QtGui.QIcon('/usr/share/icons/hicolor/48x48/hildon'
                            '/general_refresh.png')
         vars = {}
-        vars['version'] = "1.6.6"
+        vars['version'] = "1.6.9"
         message = QtCore.QString("""<center><h2>HeySms</h2></center>"""
                                  """<center>Version: %(version)s</center>"""
                                  """<br/>Visite web site: <a href="http://talk.maemo.org/showthread.php?t=84705">Here</a> """
@@ -278,6 +278,7 @@ class Ui_MainWindow(QtCore.QObject):
                                  """<li>My Doudoune</li>"""
                                  """<li>David Rodigari</li>"""
                                  """<li>Oskar Welzl</li>"""
+                                 """<li>Stefan Siegl</li>"""
                                  """</ul>"""
                                  """ """ % vars)
         QtGui.QMessageBox.about(self.main_window, "About", message)
@@ -293,6 +294,8 @@ def main():
         ui.scheduler.must_run = False
         while ui.scheduler.isRunning():
             logger.debug("Waiting scheduler")
+            if ui.scheduler.waiting_authorized_contact == True:
+                break
             sleep(0.1)
         logger.debug("Restore profile")
         config.restore_profile()
